@@ -614,7 +614,7 @@ class FlowPlot:
     def marker_choice(self):
         print('filename change: ',self.marker_file.filename)
         if True:
-            marker = pandas.read_csv('data/' + self.marker_file.filename)
+            marker = pandas.read_csv('~/.local/scpantheon-dir/data/' + self.marker_file.filename)
 
             cell_type = list(set(marker['cell_type']))
             print(cell_type)
@@ -629,7 +629,7 @@ class FlowPlot:
 
     def change_marker_ct(self):
         cell_type = self.cell_type.value
-        marker = pandas.read_csv('data/' + self.marker_file.filename)
+        marker = pandas.read_csv('~/.local/scpantheon-dir/data/' + self.marker_file.filename)
         print('+++++++marker gene')
         #cell_type = list(set(marker['cell_type']))
         if cell_type == 'No cell type':
@@ -929,11 +929,11 @@ def clear_cb(ind):
     # for i in range(len(options)):
     #     if options[i] == 'Find_Marker_Gene':
     #         ind = i
-    option = module_checkbox.labels[int(ind)]
+    option = module_checkbox.value
     models = curdoc().get_model_by_name(option)
     curdoc().remove_root(models)
     print(curdoc().get_model_by_name(option))
-    load_module(module_checkbox.active)
+    load_module(module_checkbox.value)
     # models.visible = False
     # module_checkbox.active.remove(int(ind))
 
@@ -949,14 +949,14 @@ def upload_callback(upload_button):
         global Main_plot
         filetype = os.path.splitext(upload_button.filename)[-1][1:]
         if filetype == 'csv':
-            adata = anndata.read_csv('data/'+upload_button.filename)
+            adata = anndata.read_csv('~/.local/scpantheon-dir/data/'+upload_button.filename)
             print('csv')
         elif filetype == 'h5ad':
-            adata = anndata.read('data/'+upload_button.filename)
+            adata = anndata.read('~/.local/scpantheon-dir/data/'+upload_button.filename)
             print('h5ad')
         elif filetype == 'mtx':
             adata = sc.read_10x_mtx(
-                'data/hg19/',  # the directory with the `.mtx` file
+                '~/.local/scpantheon-dir/data/hg19/',  # the directory with the `.mtx` file
                 var_names='gene_symbols',                # use gene symbols for the variable names (variables-axis index)
                 cache=True)                              # write a cache file for faster subsequent reading
         print(upload_button.filename)
